=====
medio
=====

.. image:: https://img.shields.io/pypi/v/pymedio.svg
        :target: https://pypi.python.org/pypi/pymedio

.. image:: https://readthedocs.org/projects/medio/badge/?version=latest
        :target: https://medio.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

read arbitrary medical images in python; heavily inspired by `torchio <https://github.com/fepegar/torchio>`_

* Free software: MIT license
* Documentation: https://medio.readthedocs.io.
